import {levelOption} from "@/libs/constants.js";

export const columns = (search, disable, enable, showEditExpired, showEdit, showAddAccount, showUpdatePassword) => [
  {
    title: "企业名称",
    align: "center",
    minWidth: 60,
    render: (h, { row }) => {
      const { name } = row;
      return h(
        "a",
        { on: { click: () => { showEdit(row); }} },
        name
      );
    }
  },
  {
    title: "主帐号",
    align: "center",
    minWidth: 80,
    render(h, { row }) {
      try {
        const { account } = row;
        if(account) {
          return h(
            "a",
            { on: { click: () => { showUpdatePassword(account); }} },
            account.username
          );
        } else {
          var setMainAccountTag = h(
              "Button",
              {
                  props: { type: "primary", size: "small" },
                  on: { click: () => { showAddAccount(row); }}
              },
              "设置"
          );
          return h("span", [setMainAccountTag]);
        }
      } catch(e) {
        console.log(e);
      }
    }
  },
  {
    title: "企业简称",
    key: "abbr",
    align: "center",
    minWidth: 60,
  },
  {
    title: "地址",
    key: "address",
    align: "center",
    minWidth: 60,
  },
  {
    title: "联系人",
    key: "contactName",
    align: "center",
    minWidth: 60,
  },
  {
    title: "联系电话",
    key: "contactPhone",
    align: "center",
    minWidth: 60,
  },
  {
    title: "有效期",
    key: "expiredDate",
    align: "center",
    minWidth: 60,
  },
  {
    title: "等级",
    align: "center",
    minWidth: 60,
    render: (h, { row }) => {
      const { level } = row;
      const text = levelOption.filter(item => item.value === level)[0].text;
      return h("div", text);
    }
  },
  {
    title: "地区",
    align: "center",
    minWidth: 80,
    render(h, { row }) {
      try {
        const { province, city, district } = row;
        if(province || city || district) {
          return h("span", `${province} / ${city} / ${district}`);
        }
        return h("span", `未知`);
      } catch(e) {
        console.log(e);
      }
    }
  },
  {
    title: "状态",
    align: "center",
    minWidth: 60,
    render(h, { row }) {
      try {
        const { status } = row;
        return h("span", {style: {color: status == 1 ? 'green' : 'red' }}, status == 1 ? '有效' : '失效');
      } catch(e) {
        console.log(e);
      }
    }
  },
  {
    title: "操作",
    align: "center",
    fixed: 'right',
    width: 180,
    render(h, { row }) {
      try {
        const { status } = row;
        var emptyTag = h("span","　");

        var disableTag = h(
            "Poptip",
            {
                props: { title: "确定停用当前企业吗？", transfer: true, confirm: true, size: "small" },
                on: { "on-ok": () => { row.status=0; disable(row); } }
            },
            [
                h("Button", {props: {type: "error", size: "small"}}, "停用")
            ]
        );
        var enableTag = h(
            "Button",
            {
                props: { type: "primary", size: "small" },
                on: { click: () => { row.status=1; enable(row); }}
            },
            "启用"
        );

        var updateExpiredTag = h(
            "Button",
            {
                props: { type: "primary", size: "small" },
                on: { click: () => { showEditExpired(row); }}
            },
            "有效期"
        );
        
        return h("span", status == 1 ? [updateExpiredTag, emptyTag, disableTag] : [enableTag]);
      } catch(e) {
        console.log(e);
      }
    }
  },
];
