import { paymentStatusOption } from "@/libs/constants.js";

export const columns = (search, showContract, showDriver, showVehicle, showPaying, showDelay) => [
  // {
  //   title: "id",
  //   key: "id",
  //   align: "center",
  //   width: 60,
  // },
  {
    title: "付款状态",
    align: "center",
    minWidth: 120,
    render: (h, { row }) => {
      const { paymentStatus } = row;
      const [{ text }] = paymentStatusOption.filter(item => item.value === paymentStatus);
      return h("span", text);
    }
  },
  {
    title: "状态",
    align: "center",
    width: 120,
    render(h, { row }) {
      try {
        const { status } = row;
        return h("span", {style: {color: status == 1 ? 'green' : 'red' }}, status == 1 ? '正常' : '已中止');
      } catch(e) {
        console.log(e);
      }
    }
  },
  {
    title: "费用类型",
    key: "name",
    align: "center",
    minWidth: 120,
  },
  {
    title: "合同",
    align: "center",
    minWidth: 160,
    render: (h, { row }) => {
      const { contractCode } = row;
      return h(
        "a",
        {
            on: { click: () => { 
              showContract(row);
            }}
        },
        contractCode
      );
    }
  },
  {
    title: "司机",
    align: "center",
    minWidth: 100,
    render: (h, { row }) => {
      const { driverName } = row;
      return h(
        "a",
        {
            on: { click: () => { 
              showDriver(row);
            }}
        },
        driverName
      );
    }
  },
  {
    title: "车辆",
    align: "center",
    minWidth: 100,
    render: (h, { row }) => {
      const { plateNo } = row;
      return h(
        "a",
        {
            on: { click: () => { 
              showVehicle(row);
            }}
        },
        plateNo
      );
    }
  },
  {
    title: "应收金额",
    key: "payableAmount",
    align: "center",
    minWidth: 100,
  },
  {
    title: "已收金额",
    key: "paidAmount",
    align: "center",
    minWidth: 100,
  },
  {
    title: "费用日期",
    key: "planDate",
    align: "center",
    minWidth: 100,
  },
  {
    title: "延期至",
    key: "delayDate",
    align: "center",
    minWidth: 100,
  },
  {
    title: "操作",
    align: "center",
    fixed: 'right',
    width: 130,
    render(h, { row }) {
      const { status, paymentStatus } = row;
      var emptyTag = h("span","　");
      if(status == 0 || paymentStatus==2) {
        return h("span", [emptyTag]);
      }

      var payingTag = h(
          "Button",
          {
              props: { type: "primary", size: "small" },
              on: { click: () => { showPaying(row); }}
          },
          "收款"
      );
      var delayTag = h(
          "Button",
          {
              props: { type: "primary", size: "small" },
              on: { click: () => { showDelay(row); }}
          },
          "延期"
      );
      return h("span", [payingTag, emptyTag, delayTag]);
    }
  },
];
