import store from "@/store";
const { dispatch } = store;
import moment from "moment";
import { columns } from "./helper.js";
import { Timing } from "@/components/index.js";
import { paymentStatusOption } from "@/libs/constants.js";
import Paying from "./paying/index.vue";
import Delay from "./delay/index.vue";
import EditContract from "../edit/index.vue";
import EditVehicle from "@/view/vehicle/edit/index.vue";
import EditDriver from "@/view/driver/edit/index.vue";

export default {
  components: { Timing, Paying, Delay, paymentStatusOption, EditContract, EditVehicle, EditDriver },
  data() {
    return {
      loading: false,
      loadingVisible: false,
      columns: [], 
      paymentStatusOption: paymentStatusOption,

      changeCurrent: 1,
      searchForm: {
        category: "全部",
        type: null,
        typeName: null,
        driverInfo: null,
        vehicleInfo: null,
        planDate: null,
        planDateStart: null,
        planDateEnd: null,
        paymentStatus: null,
        status: null,
      },
      data: {
        total:0,
        current: 1,
        records:[],
      },
      page: {
        size: 10,
      },
    }
  },
  watch: {
    "searchForm.category"() {
      if(this.searchForm.category == '全部') {
        this.searchForm.planDate = [];
      } else if(this.searchForm.category == '已超期') {
        this.searchForm.planDate = [moment().subtract(10, "years").format().substring(0,10), moment().subtract(1, "days").format().substring(0,10)];
      } else if(this.searchForm.category == '1周内') {
        this.searchForm.planDate = [moment().format().substring(0,10), moment().subtract(-7, "days").format().substring(0,10)];
      } else if(this.searchForm.category == '1月内') {
        this.searchForm.planDate = [moment().format().substring(0,10), moment().subtract(-30, "days").format().substring(0,10)];
      } 
      this.search();
    }
  },
  methods: {
    showEdit() {
    },
    search(current = 1) {  
      this.loading = true;
      if(this.searchForm.planDate != null) {
        this.searchForm.planDateStart = this.searchForm.planDate[0];
        this.searchForm.planDateEnd = this.searchForm.planDate[1];
      }
      dispatch("invoke/asyncSearchPlanning", {
        current,
        size: this.page.size,
        records: this.searchForm
      }).then(({ data }) => {
        this.loading = false
        if (data != null) {
          this.data = {...data};
        } else {
          this.data = {
            total:0,
            current: 1,
            records:[],
          };
        }
      });
    },
    changePage(current) {
      this.search(current);
      this.changeCurrent = current
    },
    changeSize(value) { 
      this.page.size = value
      this.search();
    },
    showContract(planning) {
      this.loadingVisible = true;
      dispatch("invoke/asyncGetContract", planning.contractId).then(({ data }) => {
        this.loadingVisible = false;
        if (data == null) {
          return;
        }
        this.$refs.editContract.contract = data;
        this.$refs.editContract.readonly = true;
        this.$refs.editContract.visible = true;
      }, (error) => {
        this.loadingVisible = false;
      });
    },
    showDriver(planning) {
      this.loadingVisible = true;
      dispatch("invoke/asyncGetDriver", planning.driverId).then(({ data }) => {
        this.loadingVisible = false;
        if (data == null) {
          return;
        }
        this.$refs.editDriver.driver = data;
        this.$refs.editDriver.readonly = true;
        this.$refs.editDriver.visible = true;
      }, (error) => {
        this.loadingVisible = false;
      });
    },
    showVehicle(planning) {
      this.loadingVisible = true;
      dispatch("invoke/asyncGetVehicle", planning.vehicleId).then(({ data }) => {
        this.loadingVisible = false;
        if (data == null) {
          return;
        }
        this.$refs.editVehicle.vehicle = data;
        this.$refs.editVehicle.readonly = true;
        this.$refs.editVehicle.visible = true;
      }, (error) => {
        this.loadingVisible = false;
      });
    },
    showPaying(planning) {
      this.$refs.paying.planning = planning;
      this.$refs.paying.visible = true;
    },
    showDelay(planning) {
      this.$refs.delay.planning = planning;
      this.$refs.delay.visible = true;
    },
  },
  mounted() {
    this.columns = columns(this.search, this.showContract, this.showDriver, this.showVehicle, this.showPaying, this.showDelay);
    this.search();
  }
};
