import store from "@/store";
const { dispatch } = store;
import { isInteger } from "@/libs/validator.js";
import { paymentStatusOption } from "@/libs/constants.js";

export default {
  components: {  },
  data() {
    return {
      planning: null,
      visible: false,
      submitLoading: false,
      payingFormRule: {
        amount: [{ required: true, message: "请输入返还金额", trigger: "blur" }, { validator: isInteger, trigger: "blur" } ],
      },
      payingForm: {
        planningId: 0,
        plateNo: null,
        paymentStatus: null,
        planDate: null,
        name: null,
        payableAmount: null,
        paidAmount: null,
        diffAmount: null,
        amount: null,
        remark: null,
      },
    };
  },
  watch: {
    // "payingForm.amount"() {
    //   if(this.payingForm.amount > this.payingForm.diffAmount) {
    //     this.setAll();
    //   }
    // },
    visible(show) {
      this.submitLoading = false;
      this.$refs.payingForm.resetFields();
      this.payingForm.planningId = null;
      this.payingForm.plateNo = null;
      this.payingForm.paymentStatus = null;
      this.payingForm.planDate = null;
      this.payingForm.name = null;
      this.payingForm.payableAmount = null;
      this.payingForm.paidAmount = null;
      this.payingForm.diffAmount = null;
      this.payingForm.amount = null;
      this.payingForm.remark = null;

      if(show) {
        this.payingForm.planningId = this.planning.id;
        this.payingForm.plateNo = this.planning.plateNo;
        this.payingForm.planDate = this.planning.planDate;
        this.payingForm.name = this.planning.name;
        this.payingForm.payableAmount = this.planning.payableAmount;
        this.payingForm.paidAmount = this.planning.paidAmount;
        this.payingForm.diffAmount = this.planning.payableAmount - this.planning.paidAmount;
        this.payingForm.paymentStatus = paymentStatusOption.filter(item => item.value === this.planning.paymentStatus)[0].text;
      }
    },
  },
  methods: {
    setAll() {
      this.payingForm.amount = "" + this.payingForm.diffAmount;
    },
    saveReturnDeposit() {
      if(this.payingForm.amount > this.payingForm.diffAmount) {
        this.$Message.error("收款金额不能超过欠收金额，已修改为：" + this.payingForm.diffAmount);
        this.setAll();
        return;
      }
      this.$refs.payingForm.validate(valid => {
        if (valid) {
          const requestData = {
            planningId: this.payingForm.planningId,
            amount: this.payingForm.amount,
            remark: this.payingForm.remark,
          }
          dispatch("invoke/asyncPaying", requestData).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success("收款成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    },
  },
  mounted() {
  }
};
