import store from "@/store";
const { dispatch } = store;
import moment from "moment";
import { isInteger } from "@/libs/validator.js";
import { feeColumns } from "./columns.js";
import AddDriver from "@/view/driver/add/index.vue";
import { leaseTypeOption } from "@/libs/constants.js";

export default {
  components: { feeColumns, leaseTypeOption, AddDriver },
  data() {
    return {
      visible: false,
      feeDialogVisible: false,
      submitLoading: false,
      feeColumns: [], 
      leaseTypeOption: leaseTypeOption,
      imageVisible: false,
      imageUrl: null,

      contractFormRule: {
        vehicleId: [{ type: "number", required: true, message: "请选择车辆", trigger: "change" }],
        driverId: [{ type: "number", required: true, message: "请选择司机", trigger: "change" }],
        odograph: [{ required: true, message: "请输入里程数", trigger: "blur" }, { validator: isInteger, trigger: "blur" } ],
        payableDepositAmount: [{ required: true, message: "请输入应付押金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
        paidDepositAmount: [{ required: true, message: "请输入实收押金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
        rentAmount: [{ required: true, message: "请输入月租金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
        firstPaidAmount: [{ required: true, message: "首次实收租金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
        leaseType: [{ type: "number", required: true, message: "请选择租赁方式", trigger: "change" }],
        startDateText: [{ type: "date", required: true, message: "请选择开始日期", trigger: "change" }],
        leasePeriod: [{ required: true, message: "请输入租赁周期", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
      },
      contractForm: {
        type: 2,
        vehicleId: null,
        driverId: null,
        odograph: null,
        odographEv: null,
        startDate: null,
        startDateText: null,
        // endDate: null,
        payableDepositAmount: null,
        paidDepositAmount: null,
        diffDepositAmount: null,
        rentAmount: null,
        firstPaidAmount: null,
        leaseType: 1,
        leasePeriod: null,
        remark: null,
        files: [],
        fees: [],
      },
      vehicles: [],
      drivers: [],

      uploadList: [],
      defaultList: [],

      allFees: [],
      selectFeeId: 0,
      leasePeriodName: "周期/月",
    };
  },
  computed: {
  },
  watch: {
    'contractForm.leaseType'() {
      if(this.contractForm.leaseType===3) {
        this.leasePeriodName = "周期/周";
      } else {
        this.leasePeriodName = "周期/月";
      }
    },
    'contractForm.payableDepositAmount'() {
      this.contractForm.diffDepositAmount = this.contractForm.payableDepositAmount - this.contractForm.paidDepositAmount;
    },
    'contractForm.paidDepositAmount'() {
      this.contractForm.diffDepositAmount = this.contractForm.payableDepositAmount - this.contractForm.paidDepositAmount;
    },
    visible(show) {
      this.submitLoading = false;
      this.$refs.contractForm.resetFields();

      if(show) {
        this.contractForm.files = [];
        this.contractForm.fees = [];
        this.uploadList = [];
        this.listVehicles();
        this.listDrivers();
        this.listEnableFees();
        // console.log(this.$refs.startDate);
        this.contractForm.startDateText = moment().format().substring(0,10);
      }
    },
    feeDialogVisible(show) {
      if(show)
        this.selectFeeId = 0;
    }
  },
  methods: {
    onAddComplete(current, driver) {
      this.drivers.unshift(driver);
      this.contractForm.driverId = driver.id;
    },
    handleView (item) {
      this.imageUrl = item.url;
      this.imageVisible = true;
    },
    handleRemove(file) {
      this.uploadList.splice(this.uploadList.indexOf(file), 1);
    },
    handleFormatError (file) {
        this.$Notice.warning({
            title: 'The file format is incorrect',
            desc: 'File format of ' + file.name + ' is incorrect, please select jpg or png.'
        });
    },
    handleMaxSize (file) {
        this.$Notice.warning({
            title: 'Exceeding file size limit',
            desc: 'File  ' + file.name + ' is too large, no more than 2M.'
        });
    },
    handleBeforeUpload(file) {
      const formData = new FormData();
      formData.append("file", file);

      const item = {id:0, url:"", status:""};
      this.uploadList.push(item);

      dispatch("invoke/asyncUploadFile", formData).then(res => {
        const { code, data, msg } = res;
        if(code == 1) {
          this.$Message.info("上传成功");

          item.id = data.id;
          item.url = data.filePath;
          item.status = "finished";
        } else {
          this.$Message.info("上传失败");
        }
      });
      return false;
    },
    saveContract() {
      this.$refs.contractForm.validate(valid => {
        if (valid) {
          this.contractForm.startDate = this.contractForm.startDateText.valueOf();
          this.uploadList.forEach(f => {
            this.contractForm.files.push(f.id);
          })
          dispatch("invoke/asyncSignContract", this.contractForm).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success("合同签订成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    },
    listVehicles() {
      dispatch("invoke/asyncListAllowRentVehicles").then(({ data }) => {
        this.vehicles = data;
      });
    },
    listDrivers() {
      dispatch("invoke/asyncListAllDriver", {}).then(({ data }) => {
        this.drivers = data;
      });
    },
    setFee(feeId) {
      if(!feeId)
        return;
      const fee = this.allFees.filter(item => item.id === feeId);
      this.contractForm.fees.push(fee[0]);
      this.feeDialogVisible = false;
    },
    firstPaidAmountChange(index, amount) {
      this.contractForm.fees[index].firstPaidAmount = amount;
    },
    removeFee(index) {
      this.contractForm.fees.splice(index, 1);
    },
    listEnableFees() {
      dispatch("invoke/asyncListFee", 1).then(({ data }) => {
        this.loading = false;
        if (data != null) {
          this.allFees = data;
        } else {
          this.allFees = [];
        }
      });
    }
  },
  mounted() {
    this.feeColumns = feeColumns(this.removeFee, this.firstPaidAmountChange);
  }
};
