import store from "@/store";
const { dispatch } = store;
import { logColumns, rentColumns } from "./helper.js";
import { leaseTypeOption } from "@/libs/constants.js";

export default {
  components: { leaseTypeOption },
  data() {
    return {
      logLoading: false,
      logDatas: [],
      logColumns: [],
      leaseTypeOption: leaseTypeOption,

      rentLoading: false,
      rentDatas: [],
      rentColumns: [],

      contract: null,
      visible: false,
      submitLoading: false,
      mainUploadStatus: false,
      secondUploadStatus: false,
      selectTab: null,

      contractForm: {
        contractId: 0,
        type: 1,
        code: null,
        vehicle: null,
        source: null,
        odograph: null,
        payableDepositAmount: null,
        paidDepositAmount: null,
        diffDepositAmount: null,
        startDate: null,
        endDate: null,
        rentAmount: null,
        leaseType: null,
        remark: null,
        files: [],
      },
      uploadList: []
    };
  },
  computed: {
  },
  watch: {
    visible(show) {
      this.submitLoading = false;
      this.contractForm.contractId = 0;
      this.contractForm.code = null;
      this.contractForm.vehicle = null;
      this.contractForm.source = null;
      this.contractForm.odograph = null;
      this.contractForm.odographEv = null;
      this.contractForm.startDate = null;
      this.contractForm.endDate = null;
      this.contractForm.rentAmount = null;
      this.contractForm.leaseType = null;
      this.contractForm.remark = null;
      this.contractForm.files = [];
      this.uploadList = [];

      if(show) {
        this.selectTab = "contractTab";
        const vo = this.contract.vehicleVo;
        const vehicleInfo = vo.id + " / " + vo.plateNo + " / " + vo.color + " / " + vo.brandName + " / " + vo.model;
        this.contractForm.contractId = this.contract.id;
        this.contractForm.code = this.contract.code;
        this.contractForm.vehicle = vehicleInfo;
        this.contractForm.source = this.contract.sourceVo.name;
        this.contractForm.odograph = this.contract.odograph;
        this.contractForm.payableDepositAmount = this.contract.payableDepositAmount;
        this.contractForm.paidDepositAmount = this.contract.paidDepositAmount;
        this.contractForm.diffDepositAmount = (this.contract.payableDepositAmount - this.contract.paidDepositAmount);
        this.contractForm.startDate = this.contract.startDate;
        this.contractForm.endDate = this.contract.endDate;
        this.contractForm.leaseType = this.contract.leaseType;
        this.contractForm.returnDepositAmount = this.contract.returnDepositAmount;
        this.contractForm.rentAmount = ""+this.contract.rentAmount;
        this.contractForm.remark = this.contract.remark;

        if(this.contract.files) {
          this.contract.files.forEach(file => {
            const item = {id: file.id, url: file.filePath, status: "finished"};
            this.uploadList.push(item);
          })
        }

        this.listContractLogs();
        this.listRentPlanning();
      } else {
        this.logDatas = [];
      }
      // console.log(this.uploadList);
      // console.log(this.contractForm);
    },
  },
  methods: {
    listVehicles() {
      dispatch("invoke/asyncListNoSourceContractVehicles").then(({ data }) => {
        this.vehicles = data;
      });
    },
    listSources() {
      dispatch("invoke/asyncListSource", {}).then(({ data }) => {
        this.sources = data;
      });
    },
    listContractLogs() {
      const contractId = this.contract.id;
      dispatch("invoke/asyncListContractLogs", contractId).then(({ data }) => {
        this.logDatas = data;
      });
    },
    listRentPlanning() {
      this.rentLoading = true;
      const requestData = { contractId: this.contract.id, type: 1 };
      dispatch("invoke/asyncListPlanningByContractId", requestData).then(({ data }) => {
        this.rentLoading = false;
        this.rentDatas = data;
      });
    },
  },
  mounted() {
    this.logColumns = logColumns();
    this.rentColumns = rentColumns();
  }
};
