import Actions from "./actions/index.vue";
import { depositStatusOption, leaseTypeOption } from "@/libs/constants.js";

export const columns = (search, showContract, showVehicle, showReturnDeposit) => [
  {
    title: "合同ID",
    key: "id",
    align: "center",
    minWidth: 50,
  },
  {
    title: "合同编号",
    align: "center",
    minWidth: 180,
    render: (h, { row }) => {
      const { code } = row;
      return h(
        "a",
        {
            on: { click: () => { 
              showContract(row, true);
            }}
        },
        code
      );
    }
  },
  {
    title: "车牌号",
    align: "center",
    minWidth: 120,
    render: (h, { row }) => {
      const { vehicleVo } = row;
      return h(
        "a",
        {
            on: { click: () => { 
              showVehicle(vehicleVo);
            }}
        },
        vehicleVo.plateNo
      );
    }
  },
  {
    title: "品牌/型号",
    align: "center",
    minWidth: 100,
    render(h, { row }) {
      try {
        const { vehicleVo } = row;
        return h("span", `${vehicleVo.brandName} / ${vehicleVo.model}`);
      } catch(e) {
        console.log(e);
      }
    }
  },
  {
    title: "车源名称",
    align: "center",
    minWidth: 120,
    render(h, { row }) {
      try {
        const { sourceVo } = row;
        return h("span", `${sourceVo.name}`);
      } catch(e) {
        console.log(e);
      }
    }
  },
  {
    title: "车源联系人",
    align: "center",
    minWidth: 120,
    render(h, { row }) {
      try {
        const { sourceVo } = row;
        return h("div", {domProps: { innerHTML: sourceVo.contactName + "<br/>" + sourceVo.contactPhone}});
      } catch(e) {
        console.log(e);
      }
    }
  },
  {
    title: "里程",
    key: "odograph",
    align: "center",
    minWidth: 100,
  },
  {
    title: "合同开始日期",
    key: "startDate",
    align: "center",
    minWidth: 120,
  },
  {
    title: "合同结束日期",
    key: "endDate",
    align: "center",
    minWidth: 120,
  },
  {
    title: "租赁方式",
    align: "center",
    minWidth: 120,
    render: (h, { row }) => {
      const { leaseType } = row;
      const [{ text }] = leaseTypeOption.filter(item => item.value === leaseType);
      return h("span", text);
    }
  },
  {
    title: "租金",
    key: "rentAmount",
    align: "center",
    minWidth: 100,
  },
  {
    title: "押金金额",
    key: "depositAmount",
    align: "center",
    minWidth: 100,
  },
  {
    title: "已返还押金金额",
    key: "returnDepositAmount",
    align: "center",
    minWidth: 100,
  },
  {
    title: "押金状态",
    align: "center",
    minWidth: 120,
    render: (h, { row }) => {
      const { depositStatus } = row;
      const [{ text }] = depositStatusOption.filter(item => item.value === depositStatus);
      var color = "red";
      if(depositStatus == 1) {
        color = "orange";
      } else if(depositStatus == 2) {
        color = "green";
      }
      return h("span", {style: {color: color }}, text);
    }
  },
  {
    title: "合同状态",
    align: "center",
    width: 120,
    render(h, { row }) {
      try {
        const { status } = row;
        return h("span", {style: {color: status == 1 ? 'green' : 'red' }}, status == 1 ? '有效' : '失效');
      } catch(e) {
        console.log(e);
      }
    }
  },
  {
    title: "操作",
    align: "center",
    fixed: 'right',
    width: 150,
    render(h, { row }) {
      const { status, depositStatus } = row;
      const params = {
        edit: status == 1 ? true : false,
        terminate: status == 1 ? true : false,
        returnDeposit: depositStatus == 1 || status == 1 ? false : true,
      };

      return h(Actions, {
        props: {
          data: row,
          params: params,
          showContract: showContract,
          showReturnDeposit: showReturnDeposit,
        }
      });
    }
  },
];
