import store from "@/store";
const { dispatch } = store;
import { isInteger } from "@/libs/validator.js";

export default {
  components: {  },
  data() {
    return {
      contract: null,
      visible: false,
      submitLoading: false,
      mainUploadStatus: false,
      secondUploadStatus: false,
      returnFormRule: {
        returnAmount: [{ required: true, message: "请输入本次退还押金", trigger: "blur" }, { validator: isInteger, trigger: "blur" }],
      },
      returnForm: {
        plateNo: null,
        depositStatus: null,
        depositAmount: null,
        returnDepositAmount: null,
        returnAmount: null,
        remark: null,
      },
    };
  },
  computed: {
  },
  watch: {
    visible(show) {
      this.submitLoading = false;
      this.$refs.returnForm.resetFields();
      this.returnForm.plateNo = null;
      this.returnForm.depositStatus = null;
      this.returnForm.depositAmount = null;
      this.returnForm.returnDepositAmount = null;
      this.returnForm.returnAmount = null;
      this.returnForm.remark = null;

      if(show) {
        this.returnForm.plateNo = this.contract.vehicleVo.plateNo;
        this.returnForm.depositAmount = this.contract.depositAmount;
        this.returnForm.returnDepositAmount = this.contract.returnDepositAmount;

        if (this.contract.depositStatus == 0) {
          this.returnForm.depositStatus = "未返还";
        } else if (this.contract.depositStatus == 1) {
          this.returnForm.depositStatus = "全部返还";
        } else if (this.contract.depositStatus == 2) {
          this.returnForm.depositStatus = "部分返还";
        }
      }
    },
  },
  methods: {
    setAll() {
      this.returnForm.returnAmount = this.returnForm.depositAmount - this.returnForm.returnDepositAmount;
    },
    saveReturnDeposit() {
      this.$refs.returnForm.validate(valid => {
        if (valid) {
          const requestData = {
            contractId: this.contract.id,
            returnAmount: this.returnForm.returnAmount,
            remark: this.returnForm.remark,
          }
          dispatch("invoke/asyncReturnDeposit", requestData).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success("返还成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    },
  },
  mounted() {
  }
};
