import store from "@/store";
const { dispatch } = store;

export default {
  components: {  },
  data() {
    return {
      visible: false,
      submitLoading: false,
      mainUploadStatus: false,
      secondUploadStatus: false,
      vehicle: null,
      readonly: false,
      vehicleFormRule: {
        plateNo: [
          {
            required: true,
            message: "请输入车牌号",
            trigger: "change"
          }
        ],
        brandId: [
          {
            required: true,
            type: 'number',
            message: "请选择品牌",
            trigger: "change"
          }
        ],
        model: [
          {
            required: true,
            message: "请选择型号",
            trigger: "change"
          }
        ],
        engineType: [
          {
            required: true,
            message: "请选择动力类型",
            trigger: "change"
          }
        ],
        displacement: [
          {
            required: true,
            message: "请输入排量",
            trigger: "change"
          }
        ],
        color: [
          {
            required: true,
            message: "请选择颜色",
            trigger: "change"
          }
        ],
      },
      vehicleForm: {
        id: 0,
        plateNo: "",
        brandId: null,
        brandName: "",
        model: "",
        engineType: "",
        displacement: "",
        color: "",
        mainFileId: 0,
        secondFileId: 0,
        mainFileUrl: null,
        secondFileUrl: null,
        type: "",
        address: "",
        useCharacter: "",
        licenseModel: "",
        vin: "",
        engineNo: "",
        registerDate: null,
        issueDate: null,
        approvedPerson: "",
        weight: "",
        outlineSize: "",
      },
      brands: [],
      models: [],
      colors: [],
      engineTypes: [],
    };
  },
  computed: {
  },
  watch: {
    visible(show) {
      this.submitLoading = false;
      this.$refs.vehicleForm.resetFields();
      this.brands = [];
      this.models = [];
      this.colors = [];
      this.engineTypes = [];

      if(show) {
        this.vehicleForm.id = this.vehicle.id;
        this.vehicleForm.mainFileId = this.vehicle.mainFileId;
        this.vehicleForm.secondFileId = this.vehicle.secondFileId;
        this.vehicleForm.mainFileUrl = this.vehicle.mainFileUrl;
        this.vehicleForm.secondFileUrl = this.vehicle.secondFileUrl;
  
        this.vehicleForm.plateNo = this.vehicle.plateNo;
        this.vehicleForm.brandId = this.vehicle.brandId;
        this.vehicleForm.brandName = this.vehicle.brandName;
        this.vehicleForm.model = this.vehicle.model;
        this.vehicleForm.engineType = this.vehicle.engineType;
        this.vehicleForm.displacement = this.vehicle.displacement;
        this.vehicleForm.color = this.vehicle.color;
        
        this.vehicleForm.type = this.vehicle.type;
        this.vehicleForm.owner = this.vehicle.owner;
        this.vehicleForm.address = this.vehicle.address;
        this.vehicleForm.useCharacter = this.vehicle.useCharacter;
        this.vehicleForm.licenseModel = this.vehicle.licenseModel;
        this.vehicleForm.vin = this.vehicle.vin;
        this.vehicleForm.engineNo = this.vehicle.engineNo;
        this.vehicleForm.registerDate = this.vehicle.registerDate;
        this.vehicleForm.issueDate = this.vehicle.issueDate;
        this.vehicleForm.approvedPerson = this.vehicle.approvedPerson;
        this.vehicleForm.weight = this.vehicle.weight;
        this.vehicleForm.outlineSize = this.vehicle.outlineSize;

        var item = {
          name: this.vehicle.model,
        }
        this.models.push(item);

        this.getBrands();
        this.getColors();
        this.getEngineTypes();
      }
    },
  },
  methods: {
    upload(formData, isMain) {
      if(isMain == 1) {
        this.mainUploadStatus = true;
      } else {
        this.secondUploadStatus = true;
      }
      dispatch("invoke/asyncUploadFile", formData).then(res => {
        const { code, data, msg } = res;
        if(code == 1) {
          this.$Message.info("上传成功");
        } else {
          this.$Message.info("上传失败");
        }
        if(isMain == 1) {
          this.mainUploadStatus = false;
          this.vehicleForm.mainFileId = data.id;
          this.vehicleForm.mainFileUrl = data.filePath;
        } else {
          this.secondUploadStatus = false;
          this.vehicleForm.secondFileId = data.id;
          this.vehicleForm.secondFileUrl = data.filePath;
        }
        this.detectVehicleLicense(data.filePath, isMain);
      });
    },
    handleUploadMain(file) {
      const formData = new FormData();
      formData.append("file", file);
      this.upload(formData, 1);
      return false;
    },
    handleUploadSecond(file) {
      const formData = new FormData();
      formData.append("file", file);
      this.upload(formData, 2);
      return false;
    },
    detectVehicleLicense(url, isMain) {
      var requestData = {
        url: url,
        isMain: isMain,
      }
      dispatch("invoke/asyncDetectVehicleLicense", requestData).then(({ data }) => {
        if(isMain == 1) {
          this.vehicleForm.type = data.type;
          this.vehicleForm.owner = data.owner;
          this.vehicleForm.address = data.address;
          this.vehicleForm.useCharacter = data.useCharacter;
          this.vehicleForm.licenseModel = data.licenseModel;
          this.vehicleForm.vin = data.vin;
          this.vehicleForm.engineNo = data.engineNo;
          this.vehicleForm.registerDate = data.registerDate;
          this.vehicleForm.issueDate = data.issueDate;
        } else {
          this.vehicleForm.approvedPerson = data.approvedPerson;
          this.vehicleForm.weight = data.weight;
          this.vehicleForm.outlineSize = data.outlineSize;
        }
      });
    },
    saveVehicle() {
      this.$refs.vehicleForm.validate(valid => {
        if (valid) {
          dispatch("invoke/asyncUpdateVehicle", this.vehicleForm).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success("修改成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    },
    brandChange(item) {
      this.models = [];
      this.vehicleForm.model = "";
      if(item) {
        this.vehicleForm.brandName = item.label;
        this.getModels(item.value);
      }
    },
    getBrands() {
      dispatch("invoke/asyncListBrand").then(({ data }) => {
        this.brands = data;
      });
    },
    getModels(brandId) {
      var requestData = {
        parentId: brandId,
      };
      dispatch("invoke/asyncListModel", requestData).then(({ data }) => {
        this.models = data;
      });
    },
    getColors() {
      dispatch("invoke/asyncListColor").then(({ data }) => {
        this.colors = data;
      });
    },
    getEngineTypes() {
      dispatch("invoke/asyncListEngineType").then(({ data }) => {
        this.engineTypes = data;
      });
    },
  },
  mounted() {
  }
};
